Test Report

# Summary

Started | 2025-12-01 11:53:15
Ended | 2025-12-01 11:53:20
Duration | 0:00:04.476465
Total run time | 0:00:02.831849

15 passed

# Warnings

## Warnings 22

- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307
- RuntimeWarning Using HARDCODED AOT value that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:305
- RuntimeWarning Using HARDCODED Angström exponent that likely does not fit to the current scene!
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/enfrosp/io/reader_enmap.py:307

# Tests

## tests/test_cli_parser.py 8 0:00:00.835457

### PASSED Test_CLIParser::test_clean_snow_grain_size_retrieval 0:00:00.221966

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.221966
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmpugqucbeq/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpugqucbeq/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpugqucbeq/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpugqucbeq/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpugqucbeq/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main 0:00:00.191950

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.191950
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmpyca0zmh8/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpyca0zmh8/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpyca0zmh8/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpyca0zmh8/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpyca0zmh8/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main_no_args 0:00:00.008697

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.008697
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_no_args 0:00:00.006149

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.006149
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.006403

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.006403
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_albedo_impurities_retrieval 0:00:00.193430

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:17
Duration | 0:00:00.193430
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 5) to /tmp/tmpfpbjhwx4/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpfpbjhwx4/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpfpbjhwx4/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpfpbjhwx4/output_imp_bba_plane.bsq.

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_broadband_albedo_retrieval 0:00:00.197578

Started | 2025-12-01 11:53:17
Ended | 2025-12-01 11:53:18
Duration | 0:00:00.197578
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /tmp/tmprycp08ze/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /tmp/tmprycp08ze/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /tmp/tmprycp08ze/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmprycp08ze/output_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_record_args_in_gui_test 0:00:00.009285

Started | 2025-12-01 11:53:18
Ended | 2025-12-01 11:53:18
Duration | 0:00:00.009285
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_io.py 4 0:00:01.464912

### PASSED TestReaderEnMAPL1C::test_create_vrt 0:00:01.043408

Started | 2025-12-01 11:53:18
Ended | 2025-12-01 11:53:19
Duration | 0:00:01.043408
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance 0:00:00.174989

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:19
Duration | 0:00:00.174989
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list 0:00:00.123508

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:19
Duration | 0:00:00.123508
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list_single_band 0:00:00.123007

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:19
Duration | 0:00:00.123007
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_retrieval.py 3 0:00:00.531480

### PASSED TestRetrieval::test_run_clean_snow_grain_size_retrieval 0:00:00.166304

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:19
Duration | 0:00:00.166304
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    The output directory /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output does not exist. Creating it now.
    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_albedo_impurities_retrieval 0:00:00.180657

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:19
Duration | 0:00:00.180657
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_imp_bba_plane.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_broadband_albedo_retrieval 0:00:00.184518

Started | 2025-12-01 11:53:19
Ended | 2025-12-01 11:53:20
Duration | 0:00:00.184518
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_BBA.bsq.
    0.17685818672180176

#### Teardown